@@ -1,5 +1,6 @@
 package Plagger::Cache;
 use strict;
+use File::Path;
 use File::Spec;
 use HTTP::Cookies;
 use UNIVERSAL::require;
@@ -32,6 +33,10 @@ sub new {
 
 sub path_to {
     my($self, @path) = @_;
+    if (@path > 1) {
+        my @chunk = @path[0..$#path-1];
+        mkpath(File::Spec->catfile(@chunk), 0, 0700);
+    }
     File::Spec->catfile($self->{base}, @path);
 }
 
